### How to Contribute to this repository 

We value contributions from the community and will do everything we can go get them reviewed in a timely fashion. If you have code to send our way or a bug to report:

* **Contributing Code**: If you have new code or a bug fix, fork this repo, create a logically-named branch, and [submit a PR against this repo](https://github.com/helium/helium-commander/issues). Include a write up of the PR with details on what it does.

* **Reporting Bugs**: Open an issue [against this repo](https://github.com/helium/helium-commander/issues) with as much detail as you can. At the very least you'll include steps to reproduce the problem.

This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant Code of Conduct](http://contributor-covenant.org/). 

Above all, thank you for taking the time to be a part of the Helium community. 